(async () => {

    // Send permission dialog to client
    const openMediaDevices = async (constraints) => {
        return await navigator.mediaDevices.getUserMedia(constraints);
    }

    try {
        const stream = await openMediaDevices({ 'video': true, 'audio': true });
        console.log('Got MediaStream:', stream);

        function updateList(elements, type) {
            const listElement = document.querySelector(type == 'video' ? 'select#availableCameras' : 'select#availableMicrophones');
            listElement.innerHTML = '';
            elements.forEach(camera => {
                const cameraOption = document.createElement('option');
                cameraOption.label = camera.label;
                cameraOption.value = camera.deviceId;
                listElement.add(cameraOption);
            });
        }

        // Fetch an array of devices of a certain type
        async function getConnectedDevices(type) {
            const devices = await navigator.mediaDevices.enumerateDevices();
            return devices.filter(device => device.kind === type)
        }

        // Listen for changes to media devices and update the list accordingly
        navigator.mediaDevices.addEventListener('devicechange', async _ => {
            updateList(await getConnectedDevices('videoinput'), 'video');
            updateList(await getConnectedDevices('audioinput'), 'audio');
        });

        updateList(await getConnectedDevices('videoinput'), 'video');
        updateList(await getConnectedDevices('audioinput'), 'audio');


        async function playVideoFromCamera() {
            try {
                const videoSelect = document.querySelector('select#availableCameras');
                const stream = await navigator.mediaDevices.getUserMedia({
                    video: {
                        deviceId: videoSelect.options[videoSelect.selectedIndex].value,
                        // width: 1920,
                        // height: 1080,
                        frameRate: 30,
                    }
                });
                const videoElement = document.querySelector('video#localVideo');
                videoElement.srcObject = stream;
            } catch (error) {
                console.error('Error opening video camera.', error);
            }
        }

        document.querySelector('button#startVideo').addEventListener('click', _ => {
            playVideoFromCamera();
        });

    } catch (error) {
        console.error('Error accessing media devices.', error);
    }
})();